@@ -139,7 +139,6 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         # We only need to find the first device.  Once we see the first device
         # multipath will have any others.
         def _wait_for_device_discovery(host_devices):
-            tries = self.tries
             for device in host_devices:
                 LOG.debug("Looking for Fibre Channel dev %(device)s",
                           {'device': device})
@@ -156,9 +155,10 @@ class FibreChannelConnector(base.BaseLinuxConnector):
 
             LOG.info("Fibre Channel volume device not yet found. "
                      "Will rescan & retry.  Try number: %(tries)s.",
-                     {'tries': tries})
+                     {'tries': self.tries})
 
-            self._linuxfc.rescan_hosts(hbas, connection_properties)
+            self._linuxfc.rescan_hosts(hbas,
+                                       connection_properties['target_lun'])
             self.tries = self.tries + 1
 
         self.host_device = None
@@ -168,11 +168,10 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             _wait_for_device_discovery, host_devices)
         timer.start(interval=2).wait()
 
-        tries = self.tries
         if self.host_device is not None and self.device_name is not None:
             LOG.debug("Found Fibre Channel volume %(name)s "
                       "(after %(tries)s rescans)",
-                      {'name': self.device_name, 'tries': tries})
+                      {'name': self.device_name, 'tries': self.tries})
 
         # find out the WWN of the device
         device_wwn = self._linuxscsi.get_scsi_wwn(self.host_device)
@@ -272,21 +271,14 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             devices.append(device_info)
 
         LOG.debug("devices to remove = %s", devices)
-        self._remove_devices(connection_properties, devices, device_info)
+        self._remove_devices(connection_properties, devices)
 
-    def _remove_devices(self, connection_properties, devices, device_info):
+    def _remove_devices(self, connection_properties, devices):
         # There may have been more than 1 device mounted
         # by the kernel for this volume.  We have to remove
         # all of them
-        path_used = self._linuxscsi.get_dev_path(connection_properties,
-                                                 device_info)
-        was_multipath = '/pci-' not in path_used
         for device in devices:
-            device_path = device['device']
-            flush = self._linuxscsi.requires_flush(device_path,
-                                                   path_used,
-                                                   was_multipath)
-            self._linuxscsi.remove_scsi_device(device_path, flush=flush)
+            self._linuxscsi.remove_scsi_device(device["device"])
 
     def _get_pci_num(self, hba):
         # NOTE(walter-boring)
