@@ -56,10 +56,9 @@ class LinuxFibreChannel(linuxscsi.LinuxSCSI):
             return [line.split('/')[4].split(':')[1:]
                     for line in out.split('\n') if line.startswith(path)]
         except Exception as exc:
-            LOG.error('Could not get HBA channel and SCSI target ID, '
-                      'path: %(path)s, reason: %(reason)s',
-                      {'path': path,
-                       'reason': exc})
+            LOG.debug('Could not get HBA channel and SCSI target ID, path: '
+                      '%(path)s, reason: %(reason)s', {'path': path,
+                                                       'reason': exc})
             return None
 
     def rescan_hosts(self, hbas, target_lun):
@@ -265,3 +264,54 @@ class LinuxFibreChannelS390X(LinuxFibreChannel):
             LOG.warning("unit_remove call for s390 failed exit %(code)s, "
                         "stderr %(stderr)s",
                         {'code': exc.exit_code, 'stderr': exc.stderr})
+
+
+class LinuxFibreChannelPPC64(LinuxFibreChannel):
+
+    def _get_hba_channel_scsi_target(self, hba, wwpn):
+        """Try to get the HBA channel and SCSI target for an HBA.
+
+        This method works for Fibre Channel targets iterating over all the
+        target wwpn port and finding the c, t, l. so caller should expect us to
+        return either None or an empty list.
+        """
+        # Leave only the number from the host_device field (ie: host6)
+        host_device = hba['host_device']
+        if host_device and len(host_device) > 4:
+            host_device = host_device[4:]
+        path = '/sys/class/fc_transport/target%s:' % host_device
+        cmd = 'grep -il %(wwpn)s %(path)s*/port_name' % {'wwpn': wwpn,
+                                                         'path': path}
+        try:
+            out, _err = self._execute(cmd, shell=True)
+            return [line.split('/')[4].split(':')[1:]
+                    for line in out.split('\n') if line.startswith(path)]
+        except Exception as exc:
+            LOG.error("Could not get HBA channel and SCSI target ID, "
+                      "reason: %s", exc)
+            return None
+
+    def rescan_hosts(self, hbas, target_lun):
+        for hba in hbas:
+            # Try to get HBA channel and SCSI target to use as filters
+            # Ignore HBA which does not have target wwn
+            if 'target_wwn' not in hba.keys():
+                continue
+            for wwpn in hba['target_wwn']:
+                cts = self._get_hba_channel_scsi_target(hba, wwpn)
+                # If we couldn't get the channel and target use wildcards
+                if not cts:
+                    cts = [('-', '-')]
+                for hba_channel, target_id in cts:
+                    LOG.debug('Scanning host %(host)s (wwpn: %(wwpn)s, c: '
+                              '%(channel)s, t: %(target)s, l: %(lun)s)',
+                              {'host': hba['host_device'],
+                               'wwpn': hba['target_wwn'],
+                               'channel': hba_channel,
+                               'target': target_id,
+                               'lun': target_lun})
+                    self.echo_scsi_command(
+                        "/sys/class/scsi_host/%s/scan" % hba['host_device'],
+                        "%(c)s %(t)s %(l)s" % {'c': hba_channel,
+                                               't': target_id,
+                                               'l': target_lun})
